@@ -73,10 +73,6 @@ KRomajiEdit::KRomajiEdit(QWidget *parent)
     m_kana = "english";
 }
 
-KRomajiEdit::~KRomajiEdit()
-{
-}
-
 QMenu *KRomajiEdit::createPopupMenu()
 {
     QMenu *menu;
@@ -85,7 +81,7 @@ QMenu *KRomajiEdit::createPopupMenu()
     menu->addSeparator();
 
     // Put our action group together
-    QActionGroup *group = new QActionGroup(menu);
+    auto group = new QActionGroup(menu);
 
     QAction *temp;
     temp = new QAction(i18nc("@option:radio selects english translation", "English"), group);
@@ -275,3 +271,5 @@ void KRomajiEdit::setKana(QAction *action)
         m_kana = "english";
     }
 }
+
+#include "moc_kromajiedit.cpp"
